@@ -24,6 +24,11 @@
 # include <inttypes.h>
 #endif
 
+#ifndef HAVE_INTMAX_T
+#define HAVE_INTMAX_T
+typedef long intmax_t;
+#endif
+
 #if !HAVE_DECL_STRTOIMAX && !defined strtoimax
 intmax_t strtoimax ();
 #endif
